@@ -3,14 +3,15 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI Utilities
 
-our $VERSION = '0.0602';
+our $VERSION = '0.0700';
 
 use strict;
 use warnings;
 
 use MIDI ();
 use MIDI::Simple ();
-use Music::Tempo;
+use Music::Chord::Note;
+use Music::Tempo qw(bpm_to_ms);
 
 
 sub setup_score {
@@ -154,6 +155,21 @@ sub midi_format {
 }
 
 
+sub add_octave {
+    my ($octave, @chord) = @_;
+    my $cn = Music::Chord::Note->new();
+    my @posn = map { $cn->scale($_) } @chord;
+    my @formatted;
+    my $last_posn = -1;
+    for my $n (0 .. $#chord) {
+        $octave = $posn[$n] > $last_posn ? $octave : ++$octave;
+        $last_posn = $posn[$n];
+        push @formatted, $chord[$n] . $octave;
+    }
+    return @formatted;
+}
+
+
 sub set_time_sig {
     my ($score, $signature) = @_;
     my ($beats, $divisions) = split /\//, $signature;
@@ -179,7 +195,7 @@ MIDI::Util - MIDI Utilities
 
 =head1 VERSION
 
-version 0.0602
+version 0.0700
 
 =head1 SYNOPSIS
 
@@ -195,10 +211,14 @@ version 0.0602
 
   my @notes = MIDI::Util::midi_format('C','C#','Db','D'); # C, Cs, Df, D
 
+  @notes = MIDI::Util::add_octave(4, qw(E G C)); # E4, G4, C5
+
 =head1 DESCRIPTION
 
 C<MIDI::Util> comprises handy MIDI utilities.
 
+Nothing is exported by default.
+
 =head1 FUNCTIONS
 
 =head2 setup_score
@@ -272,6 +292,12 @@ L<MIDI::Simple>, and L<MIDI::Event> internal lists:
 Change sharp C<#> and flat C<b>, in the list of named notes, to the
 L<MIDI::Simple> C<s> and C<f> respectively.
 
+=head2 add_octave
+
+  @formatted = MIDI::Util::add_octave($octave, @chord);
+
+Append the octave to each *named* note in the given B<chord>.
+
 =head2 set_time_sig
 
   MIDI::Util::set_time_sig( $score, $signature );
